testbin

package
v0.1.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2026 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package testbin implements the multicall container binary used by shimtest suites. It is intentionally stdlib-only so that it can be compiled as a fully static linux binary with CGO_ENABLED=0 and no external dependencies.

Callers that want to embed the binary need only call Main:

package main

import "github.com/dmcgowan/shimtest/internal/testbin"

func main() { testbin.Main() }

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Main

func Main()

Main is the entry point for the testbin multicall binary. It dispatches to the appropriate subcommand based on argv[0] (symlink mode) or argv[1] (direct invocation as "testbin <cmd>").

Types

This section is empty.

Jump to