Documentation
¶
Overview ¶
Package testbin implements the multicall container binary used by shimtest suites. It is intentionally stdlib-only so that it can be compiled as a fully static linux binary with CGO_ENABLED=0 and no external dependencies.
Callers that want to embed the binary need only call Main:
package main
import "github.com/dmcgowan/shimtest/internal/testbin"
func main() { testbin.Main() }
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.